'Filename   USB-Kopplung_003.bas
'Date       2020-06-30
'Purpose    Test USB communication from ATmega328P to PC
'           Transfer numeric data, simple data logging with a sine function
'           BASCOM "Serialout" is used.
'           Data are stored in a serial buffer and transmitted byte by byte
'           by an interrupt service routine in the background.
'           Global interrupts must be enabled!
'Author     Georg Latzel, DL6GL
'Copyright  (c) Georg Latzel, free for private use under GNU license
'Hardware   Arduino UNO, ATmega328p, Crystal 16 MHz
'           LED   PortD.2
'Compiler   BASCOM-AVR 2.0.8.2
'           For readable "camel case" variables mark "Don't change case"
'           in BASCOM Options-Programmer-Environment-Editor
'Edit history
'           2020-06-30
'           First release
'           Flash used: 2,016 bytes (6%)

'==============================================================================

'FUSE-Bits (AVR Studio 4.0-Settings, [ ]=no check, [x]=check)
'In ATMEGA-Data sheets: Bit = 1 -> not set = no check
'                       Bit = 0 -> set     = check
'BODLEVEL   Brown-out detection at VCC=4.3V
'RSTDISBL   [ ]
'DWEN       [ ]
'SPIEN      [x] Do not change!
'WDTON      [ ]
'EESAVE     [ ]
'BOOTSZ     Boot Flash size=256 words (minimal boot size)
'BOOTRST    [ ]
'CKDIV8     [ ]
'CKOUT      [ ]
'SUT_CKSEL  Ext. Crystal Osc. 8.0- MHz, Start-up time 16k + 14ms
'Extended:  0xFC
'High:      0xDF
'Low:       0xFF


$regfile = "m328pdef.dat"                         'ATMega328P
$crystal = 16000000                               '16 MHz xtal
$hwstack = 40
$swstack = 40
$framesize = 40
$Baud = 9600                                      '9600 Baud, 8N1

DDRD = &B00000100                                 'PD.2=Output LED
PORTD = &B11111011
LED Alias PORTD.2

Dim sngX As Single
Dim sngY As Single

Config Serialout = Buffered , Size = 10
SReg.7 = 1                                        'Enable global interrupts

LED = 0
sngX = 0

Do

      Toggle LED
      sngY = SIN(sngX)
      Print Fusing(sngY , "#.###")
      Waitms 200
      sngX = sngX + 0.1

Loop


End